@@ -36,10 +36,8 @@ class HttpConnector : public QObject {
                 void setRequestTimeout ();
 
         signals:
-                void getResponseContent (bool,QString*);
-                void getRawData (bool,QByteArray);
+                void getResponseContent (QByteArray,int);
                 void isFree();
-                void getHttpResponseCode (int);
 
         private:
                 QNetworkAccessManager *http;
