@@ -10,7 +10,7 @@ MaemoApplicationDetails::MaemoApplicationDetails() {
             installFile="";
             installFileContent="";
             status="";
-            unparsedComments = new QString("");
+            unparsedComments = QByteArray();
  }
 
 MaemoApplicationDetails::~MaemoApplicationDetails () {
@@ -52,11 +52,11 @@ void MaemoApplicationDetails::setCommentsList (QList <MaemoComment*> *cl) {
     this->userComments = cl;
 }
 
-void MaemoApplicationDetails::setUnparsedComments (QString *c) {
+void MaemoApplicationDetails::setUnparsedComments (QByteArray c) {
     this->unparsedComments = c;
 }
 
-QString* MaemoApplicationDetails::getUnparsedComments() {
+QByteArray MaemoApplicationDetails::getUnparsedComments() {
     qDebug() << "return unparsedComments";
     return this->unparsedComments;
 }
