@@ -43,7 +43,7 @@ class MaemoApplicationHandler : public QObject {
             void requestInstallFile (QString url);
             void requestCategories (QString OS = "Maemo5");
             void requestLogin (QString uname,QString pw);
-            void parseCommentsOnly (QString *);
+            void parseCommentsOnly (QByteArray, int preloadComments = -1);
             void emptyQueue();
             bool isUserLoggedIn ();
             void logOut();
@@ -56,17 +56,17 @@ class MaemoApplicationHandler : public QObject {
             QString formalizeQString (QString);
     private slots:
             // private slots to proceed the requests
-            void parseAppListResponse (bool,QString*);
-            void parseSingleAppResponse (bool,QString*);
-            void parseCategoryResponse (bool, QString*);
-            void proceedImageResponse (bool, QByteArray);
-            void loginResponse (int);
-            void commentResponse (int);
+            void parseAppListResponse (QByteArray,int);
+            void parseSingleAppResponse (QByteArray,int);
+            void parseCategoryResponse (QByteArray,int);
+            void proceedImageResponse (QByteArray,int);
+            void loginResponse (QByteArray,int);
+            void commentResponse (QByteArray,int);
             void proceedQueue ();
 
 
     public slots:
-            void proceedInstallFileResponse (bool, QString*);
+            void proceedInstallFileResponse (QByteArray, int);
     signals:
             //signals returning the responses of the requests
             // application list
@@ -82,7 +82,7 @@ class MaemoApplicationHandler : public QObject {
             //logged in
             void loggedIn (int);
             void commented (int);
-            void raiseError (QString*);
+            void raiseError (QString);
 
     private:
             QString OCS_URL;
